@@ -4,12 +4,10 @@ package Methods::CheckNames;
 
 use strict;
 use warnings;
-use B::Hooks::OP::Check;
-use B::Hooks::OP::PPAddr;
-use B::Hooks::EndOfScope;
-use namespace::clean;
 
-our $VERSION = "0.05_01";
+use XSLoader;
+
+our $VERSION = "0.01";
 
 eval {
 	require XSLoader;
@@ -21,19 +19,6 @@ eval {
 	__PACKAGE__->bootstrap($VERSION);
 };
 
-sub import {
-    my ($class) = @_;
-    my $caller = caller;
-
-    my $hook = $class->setup;
-
-    on_scope_end {
-        $class->teardown($hook);
-    };
-
-    return;
-}
-
 __PACKAGE__
 
 __END__
@@ -68,12 +53,18 @@ Use the C<can> meta method instead of C<gv_fetchmethod>
 
 Make the checking pluggable
 
+=item *
+
+Checking should be lexically scoped. Not a huge issue for now, since C<my Foo
+$var> is not commonly used.
+
 =back
 
 =head1 VERSION CONTROL
 
-This module is maintained using git. You can get the latest version from
-L<git://github.com/rafl/methods-checknames.git>.
+This module is maintained using Darcs. You can get the latest version from
+L<http://nothingmuch.woobling.org/code>, and use C<darcs send> to commit
+changes.
 
 =head1 AUTHOR
 
